@@ -1,11 +1,14 @@
+from __future__ import annotations
+
 import json
 import logging
+from collections.abc import Generator, Sequence
 from email.parser import Parser
 from optparse import Values
-from typing import TYPE_CHECKING, Generator, List, Optional, Sequence, Tuple, cast
+from typing import TYPE_CHECKING, cast
 
 from pipenv.patched.pip._vendor.packaging.utils import canonicalize_name
-from pipenv.patched.pip._vendor.packaging.version import Version
+from pipenv.patched.pip._vendor.packaging.version import InvalidVersion, Version
 
 from pipenv.patched.pip._internal.cli import cmdoptions
 from pipenv.patched.pip._internal.cli.index_command import IndexGroupCommand
@@ -140,8 +143,8 @@ class ListCommand(IndexGroupCommand):
             super().handle_pip_version_check(options)
 
     def _build_package_finder(
-        self, options: Values, session: "PipSession"
-    ) -> "PackageFinder":
+        self, options: Values, session: PipSession
+    ) -> PackageFinder:
         """
         Create a package finder appropriate to this list command.
         """
@@ -162,7 +165,7 @@ class ListCommand(IndexGroupCommand):
             selection_prefs=selection_prefs,
         )
 
-    def run(self, options: Values, args: List[str]) -> int:
+    def run(self, options: Values, args: list[str]) -> int:
         if options.outdated and options.uptodate:
             raise CommandError("Options --outdated and --uptodate cannot be combined.")
 
@@ -204,8 +207,8 @@ class ListCommand(IndexGroupCommand):
         return SUCCESS
 
     def get_outdated(
-        self, packages: "_ProcessedDists", options: Values
-    ) -> "_ProcessedDists":
+        self, packages: _ProcessedDists, options: Values
+    ) -> _ProcessedDists:
         return [
             dist
             for dist in self.iter_packages_latest_infos(packages, options)
@@ -213,8 +216,8 @@ class ListCommand(IndexGroupCommand):
         ]
 
     def get_uptodate(
-        self, packages: "_ProcessedDists", options: Values
-    ) -> "_ProcessedDists":
+        self, packages: _ProcessedDists, options: Values
+    ) -> _ProcessedDists:
         return [
             dist
             for dist in self.iter_packages_latest_infos(packages, options)
@@ -222,8 +225,8 @@ class ListCommand(IndexGroupCommand):
         ]
 
     def get_not_required(
-        self, packages: "_ProcessedDists", options: Values
-    ) -> "_ProcessedDists":
+        self, packages: _ProcessedDists, options: Values
+    ) -> _ProcessedDists:
         dep_keys = {
             canonicalize_name(dep.name)
             for dist in packages
@@ -236,14 +239,14 @@ class ListCommand(IndexGroupCommand):
         return list({pkg for pkg in packages if pkg.canonical_name not in dep_keys})
 
     def iter_packages_latest_infos(
-        self, packages: "_ProcessedDists", options: Values
-    ) -> Generator["_DistWithLatestInfo", None, None]:
+        self, packages: _ProcessedDists, options: Values
+    ) -> Generator[_DistWithLatestInfo, None, None]:
         with self._build_session(options) as session:
             finder = self._build_package_finder(options, session)
 
             def latest_info(
-                dist: "_DistWithLatestInfo",
-            ) -> Optional["_DistWithLatestInfo"]:
+                dist: _DistWithLatestInfo,
+            ) -> _DistWithLatestInfo | None:
                 all_candidates = finder.find_all_candidates(dist.canonical_name)
                 if not options.pre:
                     # Remove prereleases
@@ -274,7 +277,7 @@ class ListCommand(IndexGroupCommand):
                     yield dist
 
     def output_package_listing(
-        self, packages: "_ProcessedDists", options: Values
+        self, packages: _ProcessedDists, options: Values
     ) -> None:
         packages = sorted(
             packages,
@@ -285,17 +288,19 @@ class ListCommand(IndexGroupCommand):
             self.output_package_listing_columns(data, header)
         elif options.list_format == "freeze":
             for dist in packages:
+                try:
+                    req_string = f"{dist.raw_name}=={dist.version}"
+                except InvalidVersion:
+                    req_string = f"{dist.raw_name}==={dist.raw_version}"
                 if options.verbose >= 1:
-                    write_output(
-                        "%s==%s (%s)", dist.raw_name, dist.version, dist.location
-                    )
+                    write_output("%s (%s)", req_string, dist.location)
                 else:
-                    write_output("%s==%s", dist.raw_name, dist.version)
+                    write_output(req_string)
         elif options.list_format == "json":
             write_output(format_for_json(packages, options))
 
     def output_package_listing_columns(
-        self, data: List[List[str]], header: List[str]
+        self, data: list[list[str]], header: list[str]
     ) -> None:
         # insert the header first: we need to know the size of column names
         if len(data) > 0:
@@ -312,8 +317,8 @@ class ListCommand(IndexGroupCommand):
 
 
 def format_for_columns(
-    pkgs: "_ProcessedDists", options: Values
-) -> Tuple[List[List[str]], List[str]]:
+    pkgs: _ProcessedDists, options: Values
+) -> tuple[list[list[str]], list[str]]:
     """
     Convert the package data into something usable
     by output_package_listing_columns.
@@ -324,7 +329,7 @@ def format_for_columns(
     if running_outdated:
         header.extend(["Latest", "Type"])
 
-    def wheel_build_tag(dist: BaseDistribution) -> Optional[str]:
+    def wheel_build_tag(dist: BaseDistribution) -> str | None:
         try:
             wheel_file = dist.read_text("WHEEL")
         except FileNotFoundError:
@@ -371,12 +376,16 @@ def format_for_columns(
     return data, header
 
 
-def format_for_json(packages: "_ProcessedDists", options: Values) -> str:
+def format_for_json(packages: _ProcessedDists, options: Values) -> str:
     data = []
     for dist in packages:
+        try:
+            version = str(dist.version)
+        except InvalidVersion:
+            version = dist.raw_version
         info = {
             "name": dist.raw_name,
-            "version": str(dist.version),
+            "version": version,
         }
         if options.verbose >= 1:
             info["location"] = dist.location or ""
