@@ -8,6 +8,7 @@ from typing import Dict, Set, Tuple
 from pipenv.exceptions import JSONParseError, PipenvCmdError
 from pipenv.patched.pip._vendor.packaging.specifiers import SpecifierSet
 from pipenv.patched.pip._vendor.packaging.version import InvalidVersion, Version
+from pipenv.routines.lock import overwrite_with_default
 from pipenv.routines.outdated import do_outdated
 from pipenv.routines.sync import do_sync
 from pipenv.utils import err
@@ -202,10 +203,46 @@ def check_version_conflicts(
     return conflicts
 
 
+def _locked_version_satisfies_pipfile_specifier(pipfile_specifier, locked_version):
+    """
+    Check if the locked version satisfies the Pipfile specifier.
+
+    Args:
+        pipfile_specifier: Version specifier from Pipfile (e.g., "*", ">=2.25.1", "==1.0.0")
+        locked_version: Version string from lockfile (e.g., "==2.31.0")
+
+    Returns:
+        True if the locked version satisfies the Pipfile specifier, False otherwise.
+    """
+    # Handle wildcard - any version is acceptable
+    if pipfile_specifier == "*":
+        return True
+
+    # Extract the actual version number from the locked version (remove "==")
+    if locked_version.startswith("=="):
+        version_str = locked_version[2:]
+    else:
+        version_str = locked_version
+
+    try:
+        # Parse the Pipfile specifier and check if locked version satisfies it
+        specifier_set = SpecifierSet(pipfile_specifier)
+        version = Version(version_str)
+        return version in specifier_set
+    except (InvalidVersion, ValueError):
+        # If we can't parse, fall back to string comparison
+        return pipfile_specifier == locked_version
+
+
 def get_modified_pipfile_entries(project, pipfile_categories):
     """
     Detect Pipfile entries that have been modified since the last lock.
     Returns a dict mapping categories to sets of InstallRequirement objects.
+
+    A package is considered "modified" if:
+    - It's new (not in lockfile)
+    - Its version specifier has changed such that the locked version no longer satisfies it
+    - Its VCS URL, ref, or extras have changed
     """
     modified = defaultdict(dict)
     lockfile = project.lockfile()
@@ -223,16 +260,23 @@ def get_modified_pipfile_entries(project, pipfile_categories):
 
             locked_entry = locked_packages[package_name]
             is_modified = False
+            locked_version = locked_entry.get("version", "")
 
-            # For string entries, compare directly
+            # For string entries (version specifier only)
             if isinstance(pipfile_entry, str):
-                if pipfile_entry != locked_entry.get("version", ""):
+                # Check if locked version still satisfies the Pipfile specifier
+                if not _locked_version_satisfies_pipfile_specifier(
+                    pipfile_entry, locked_version
+                ):
                     is_modified = True
 
             # For dict entries, need to compare relevant fields
             elif isinstance(pipfile_entry, dict):
                 if "version" in pipfile_entry:
-                    if pipfile_entry["version"] != locked_entry.get("version", ""):
+                    # Check if locked version still satisfies the Pipfile specifier
+                    if not _locked_version_satisfies_pipfile_specifier(
+                        pipfile_entry["version"], locked_version
+                    ):
                         is_modified = True
 
                 # Compare VCS fields
@@ -347,6 +391,7 @@ def _process_package_args(
     category,
     has_package_args,
     requested_packages,
+    lock_only=False,
 ):
     """Process package arguments and update requested_packages."""
     for package in package_args[:]:
@@ -357,9 +402,14 @@ def _process_package_args(
         )
 
         # Only add to Pipfile if this category was explicitly requested for this package
-        if has_package_args and (
-            normalized_name not in explicitly_requested
-            or category in explicitly_requested.get(normalized_name, [])
+        # and lock_only is not set
+        if (
+            not lock_only
+            and has_package_args
+            and (
+                normalized_name not in explicitly_requested
+                or category in explicitly_requested.get(normalized_name, [])
+            )
         ):
             project.add_pipfile_entry_to_pipfile(
                 name, normalized_name, pipfile_entry, category=pipfile_category
@@ -396,8 +446,14 @@ def _resolve_and_update_lockfile(
     if not requested_packages[pipfile_category]:
         return None
 
+    # Use package_args if provided, otherwise use the keys from requested_packages
+    package_names = (
+        package_args
+        if package_args
+        else list(requested_packages[pipfile_category].keys())
+    )
     err.print(
-        f"[bold][green]Upgrading[/bold][/green] {', '.join(package_args)} in [{category}] dependencies."
+        f"[bold][green]Upgrading[/bold][/green] {', '.join(package_names)} in [{category}] dependencies."
     )
 
     # Resolve package to generate constraints of new package data
@@ -565,6 +621,7 @@ def upgrade(
                 category,
                 has_package_args,
                 requested_packages,
+                lock_only=lock_only,
             )
 
         # Resolve dependencies and update lockfile
@@ -604,6 +661,16 @@ def upgrade(
         if not has_package_args:
             package_args = []
 
+    # Overwrite any non-default category packages with default packages (if present)
+    # This ensures transitive dependencies in develop match the versions from default
+    for category in categories:
+        if category == "default":
+            continue
+        if lockfile.get(category):
+            lockfile[category].update(
+                overwrite_with_default(lockfile.get("default", {}), lockfile[category])
+            )
+
     # Update and write lockfile
     lockfile.update({"_meta": project.get_lockfile_meta()})
     project.write_lockfile(lockfile)
