@@ -69,6 +69,57 @@ def _get_activate_script(cmd, venv):
     return f" {command} {venv_location}/bin/activate{suffix}"
 
 
+def _get_deactivate_wrapper_script(cmd):
+    """Returns a script to wrap the deactivate function to also unset PIPENV_ACTIVE.
+
+    This ensures that when a user runs 'deactivate' in a pipenv shell, the
+    PIPENV_ACTIVE environment variable is also cleared, allowing subsequent
+    'pipenv shell' commands to work without the 'already activated' error.
+    """
+    if cmd.endswith("fish"):
+        # Fish shell uses 'functions' and 'set -e' to unset variables
+        return (
+            "functions -c deactivate _pipenv_old_deactivate; "
+            "function deactivate; _pipenv_old_deactivate; set -e PIPENV_ACTIVE; end"
+        )
+    elif cmd.endswith("csh"):
+        # C shell uses 'unsetenv'
+        return (
+            "alias _pipenv_old_deactivate deactivate; "
+            "alias deactivate '_pipenv_old_deactivate; unsetenv PIPENV_ACTIVE'"
+        )
+    elif cmd.endswith("xonsh"):
+        # Xonsh uses Python-like syntax
+        return (
+            "_pipenv_old_deactivate = deactivate; "
+            "def deactivate(): _pipenv_old_deactivate(); del $PIPENV_ACTIVE"
+        )
+    elif cmd.endswith("nu"):
+        # Nushell - deactivate is typically handled differently
+        # For now, return empty as nu has different paradigm
+        return ""
+    elif cmd.endswith(("pwsh", "powershell")):
+        # PowerShell
+        return (
+            "$_pipenv_old_deactivate = $function:deactivate; "
+            "function deactivate { & $_pipenv_old_deactivate; "
+            "Remove-Item Env:PIPENV_ACTIVE -ErrorAction SilentlyContinue }"
+        )
+    elif cmd.endswith(("bash", "zsh")):
+        # Bash and zsh support 'declare -f' to copy function definitions
+        return (
+            'eval "_pipenv_old_deactivate() { $(declare -f deactivate | tail -n +2) }"; '
+            "deactivate() { _pipenv_old_deactivate; unset PIPENV_ACTIVE; }"
+        )
+    elif cmd.endswith("sh"):
+        # Plain POSIX sh doesn't have 'declare -f', use a simpler approach
+        # Just redefine deactivate to call the original via sourcing and add unset
+        return "deactivate() { command deactivate 2>/dev/null; unset PIPENV_ACTIVE; }"
+    else:
+        # Unknown shell - return empty string
+        return ""
+
+
 def _handover(cmd, args):
     args = [cmd] + args
     if os.name != "nt":
@@ -115,8 +166,20 @@ class Shell:
         # dimensions of pexpect.
         dims = get_terminal_size()
         with temp_environ():
+            # Unset COLUMNS and LINES so the spawned shell can manage them.
+            # When these are exported, Bash treats them as read-only inherited
+            # values and doesn't update them on terminal resize, even with
+            # checkwinsize enabled. See: https://github.com/pypa/pipenv/issues/6169
+            os.environ.pop("COLUMNS", None)
+            os.environ.pop("LINES", None)
             c = pexpect.spawn(self.cmd, ["-i"], dimensions=(dims.lines, dims.columns))
         c.sendline(_get_activate_script(self.cmd, venv))
+
+        # Wrap the deactivate function to also unset PIPENV_ACTIVE
+        deactivate_wrapper = _get_deactivate_wrapper_script(self.cmd)
+        if deactivate_wrapper:
+            c.sendline(deactivate_wrapper)
+
         if args:
             c.sendline(" ".join(args))
 
